@@ -2,6 +2,6 @@
   packageStartupMessage(
     "You can cite this package as:
      Patil, I. (2021). Visualizations with statistical details: The 'ggstatsplot' approach.
-     PsyArxiv. doi:10.31234/osf.io/p7mku"
+     Journal of Open Source Software, 6(61), 3167, doi:10.21105/joss.03167"
   )
 }
