@@ -1,4 +1,4 @@
-#' @title Bar (column) charts with statistical tests
+#' @title Stacked bar charts with statistical tests
 #' @name ggbarstats
 #'
 #' @description
@@ -6,10 +6,8 @@
 #' Bar charts for categorical data with statistical details included in the plot
 #' as a subtitle.
 #'
-#' @param xlab Custom text for the `x` axis label (Default: `NULL`, which
-#'   will cause the `x` axis label to be the `x` variable).
-#' @param ylab Custom text for the `y` axis label (Default: `NULL`).
 #' @inheritParams ggpiestats
+#' @inheritParams ggbetweenstats
 #'
 #' @seealso \code{\link{grouped_ggbarstats}}, \code{\link{ggpiestats}},
 #'  \code{\link{grouped_ggpiestats}}
@@ -26,8 +24,6 @@
 #' ggbarstats(mtcars, x = vs, y = cyl)
 #' }
 #' @export
-
-# defining the function
 ggbarstats <- function(data,
                        x,
                        y,
@@ -84,7 +80,6 @@ ggbarstats <- function(data,
 
   # statistical analysis ------------------------------------------
 
-  # if subtitle with results is to be displayed
   if (results.subtitle) {
     # relevant arguments for statistical tests
     .f.args <- list(
@@ -97,8 +92,7 @@ ggbarstats <- function(data,
       ratio               = ratio,
       sampling.plan       = sampling.plan,
       fixed.margin        = fixed.margin,
-      prior.concentration = prior.concentration,
-      top.text            = caption
+      prior.concentration = prior.concentration
     )
 
     subtitle_df <- eval_f(contingency_table, !!!.f.args, type = type)
@@ -131,7 +125,7 @@ ggbarstats <- function(data,
   palette_message(package, palette, nlevels(data %>% pull({{ x }})))
 
   # plot
-  p <- ggplot(descriptive_df, aes({{ y }}, perc, fill = {{ x }})) +
+  plotBar <- ggplot(descriptive_df, aes({{ y }}, perc, fill = {{ x }})) +
     geom_bar(stat = "identity", position = "fill", color = "black") +
     scale_y_continuous(
       labels       = function(x) paste0(x * 100, "%"),
@@ -153,8 +147,7 @@ ggbarstats <- function(data,
 
   # adding significance labels to bars for proportion tests
   if (isTRUE(proportion.test)) {
-    # modify plot
-    p <- p +
+    plotBar <- plotBar +
       geom_text(
         data    = onesample_df,
         mapping = aes(x = {{ y }}, y = 1.05, label = .p.label, fill = NULL),
@@ -164,7 +157,7 @@ ggbarstats <- function(data,
   }
 
   # adding sample size info
-  p <- p +
+  plotBar <- plotBar +
     geom_text(
       data    = onesample_df,
       mapping = aes(x = {{ y }}, y = -0.05, label = N, fill = NULL),
@@ -173,8 +166,7 @@ ggbarstats <- function(data,
 
   # annotations ------------------------------------------
 
-  # preparing the plot
-  p +
+  plotBar +
     labs(
       x        = xlab %||% as_name(y),
       y        = ylab,
@@ -228,8 +220,6 @@ ggbarstats <- function(data,
 #' )
 #' }
 #' @export
-
-# defining the function
 grouped_ggbarstats <- function(data,
                                ...,
                                grouping.var,
@@ -249,6 +239,5 @@ grouped_ggbarstats <- function(data,
   # combining the list of plots into a single plot
   if (output == "plot") p_ls <- combine_plots(p_ls, plotgrid.args, annotation.args)
 
-  # return the object
   p_ls
 }
