@@ -113,8 +113,6 @@
 #' ggcoefstats(mod, output = "glance")
 #' }
 #' @export
-
-# function body
 ggcoefstats <- function(x,
                         output = "plot",
                         statistic = NULL,
@@ -151,20 +149,20 @@ ggcoefstats <- function(x,
                         palette = "Dark2",
                         ggtheme = ggstatsplot::theme_ggstatsplot(),
                         ...) {
-  # dataframe -------------------------
 
-  if (isFALSE(insight::is_model(x))) {
-    # set tidy_df to entered dataframe
+  # model check -------------------------
+
+  # if a data frame is entered then `statistic` is necessary to create labels
+  if (!insight::is_model(x)) {
     tidy_df <- as_tibble(x)
-
-    # check that `statistic` is specified
     if (is.null(statistic)) stats.labels <- FALSE
   }
 
-  # tidy it -------------------------
+  # tidy dataframe -------------------------
+
+  if (insight::is_model(x)) {
+    statistic <- insight::find_statistic(x)
 
-  if (isTRUE(insight::is_model(x))) {
-    # which effect size?
     eta_squared <- omega_squared <- NULL
     if (effsize == "eta") eta_squared <- "partial"
     if (effsize == "omega") omega_squared <- "partial"
@@ -186,12 +184,10 @@ ggcoefstats <- function(x,
     if (all(c("df", "df.error") %in% names(tidy_df))) tidy_df %<>% mutate(effectsize = paste0("partial ", effsize, "-squared"))
   }
 
-
   # tidy dataframe cleanup -------------------------
 
-  # check for the one necessary column
   if (is.null(tidy_df) || !"estimate" %in% names(tidy_df)) {
-    stop("The tidy dataframe *must* contain 'estimate' column.", call. = FALSE)
+    rlang::abort("The tidy dataframe *must* contain 'estimate' column.")
   }
 
   # create a new term column if it's not present
@@ -201,8 +197,7 @@ ggcoefstats <- function(x,
 
   # check for duplicate terms and columns -------------------------
 
-  # a check if there are repeated terms
-  # needed for maov, lqm, lqmm, etc. kind of objects
+  # check if there are repeated terms (relevant for `maov`, `lqm`, etc.)
   if (any(duplicated(select(tidy_df, term)))) {
     tidy_df %<>%
       tidyr::unite(
@@ -214,19 +209,17 @@ ggcoefstats <- function(x,
   }
 
   # halt if there are still repeated terms
-  if (any(duplicated(tidy_df$term))) stop("Elements in `term` column must be unique.")
+  if (any(duplicated(tidy_df$term))) rlang::abort("Elements in `term` column must be unique.")
 
-  # if `parameters` output doesn't contain p-value or statistic column
-  if (sum(c("p.value", "statistic") %in% names(tidy_df)) != 2L) stats.labels <- FALSE
+  # if tidy data frame doesn't contain p-value or statistic column, a label
+  # can't be prepared
+  if (!(all(c("p.value", "statistic") %in% names(tidy_df)))) stats.labels <- FALSE
 
   # CIs and intercepts -------------------------
 
-  # if `parameters` output doesn't contain CI
+  # if tidy data frame doesn't contain CIs, show only the estimate dots
   if (!"conf.low" %in% names(tidy_df)) {
-    # add NAs so that only dots will be shown
     tidy_df %<>% mutate(conf.low = NA, conf.high = NA)
-
-    # stop displaying whiskers
     conf.int <- FALSE
   }
 
@@ -235,11 +228,7 @@ ggcoefstats <- function(x,
 
   # preparing label -------------------------
 
-  # adding a column with labels to be used with `ggrepel`
   if (stats.labels) {
-    # extract statistic for a model
-    if (insight::is_model(x)) statistic <- insight::find_statistic(x)
-
     # remove NAs
     tidy_df %<>%
       filter(if_any(
@@ -249,81 +238,52 @@ ggcoefstats <- function(x,
       statsExpressions::tidy_model_expressions(statistic, k, effsize)
 
     # only significant p-value labels are shown
-    if (only.significant && "p.value" %in% names(tidy_df)) {
-      tidy_df %<>% mutate(label = ifelse(p.value >= 0.05, NA, label))
+    if (only.significant && ("p.value" %in% names(tidy_df))) {
+      tidy_df %<>% mutate(expression = ifelse(p.value >= 0.05, list(NULL), expression))
     }
   }
 
   # sorting -------------------------
 
-  # whether the term need to be arranged in any specified order
-  tidy_df %<>% mutate(term = as.factor(term), .rowid = row_number())
+  if (utils::packageVersion("parameters") >= "0.17.1" && requireNamespace("parameters")) {
 
-  # sorting factor levels
-  new_order <- switch(sort,
-    "ascending" = order(tidy_df$estimate, decreasing = FALSE),
-    "descending" = order(tidy_df$estimate, decreasing = TRUE),
-    order(tidy_df$.rowid, decreasing = FALSE)
-  )
+    # whether the terms need to be sorted in specified order
+    tidy_df %<>% sort_parameters(sort = sort, column = "estimate")
 
-  # sorting `term` factor levels according to new sorting order
-  tidy_df %<>%
-    mutate(term = as.character(term)) %>%
-    mutate(term = factor(x = term, levels = term[new_order])) %>%
-    select(-.rowid)
+    # `term` needs to be a factor column; otherwise, ggplot2 will sort the x-axis
+    # labels alphabetically and terms won't appear in the expected order
+    tidy_df %<>% dplyr::mutate(term = factor(term, tidy_df$term))
+  }
 
   # summary caption -------------------------
 
-  # for non-dataframe objects
-  if (insight::is_model(x)) {
-    # creating glance dataframe
-    glance_df <- performance::model_performance(x, verbose = FALSE)
+  glance_df <- performance::model_performance(x, verbose = FALSE) %>% as_tibble()
 
-    # no meta-analysis in this context
-    meta.analytic.effect <- FALSE
-
-    # if glance is not available, inform the user
-    if (!is.null(glance_df) && all(c("AIC", "BIC") %in% names(glance_df))) {
-      # preparing caption with model diagnostics
-      caption <- substitute(
-        expr = atop(displaystyle(top.text), expr = paste("AIC = ", AIC, ", BIC = ", BIC)),
-        env = list(
-          top.text = caption,
-          AIC = format_value(glance_df$AIC[[1]], 0L),
-          BIC = format_value(glance_df$BIC[[1]], 0L)
-        )
-      )
-    }
+  if (!is.null(glance_df) && all(c("AIC", "BIC") %in% names(glance_df))) {
+    glance_df %<>% mutate(expression = list(parse(text = glue("list(AIC=='{format_value(AIC, 0L)}', BIC=='{format_value(BIC, 0L)}')"))))
+    caption <- glance_df$expression[[1]]
   }
 
-  # running meta-analysis
+  # meta analysis -------------------------
+
   if (meta.analytic.effect) {
     # standardizing type of statistics name
     meta.type <- stats_type_switch(meta.type)
 
     # results from frequentist random-effects meta-analysis
-    subtitle_df <- statsExpressions::meta_analysis(tidy_df, type = meta.type, k = k)
-
+    subtitle_df <- meta_analysis(tidy_df, type = meta.type, k = k)
     subtitle <- subtitle_df$expression[[1]]
 
     # results from Bayesian random-effects meta-analysis (only for parametric)
     if (meta.type == "parametric" && bf.message) {
-      caption_df <- statsExpressions::meta_analysis(
-        tidy_df,
-        type     = "bayes",
-        k        = k,
-        top.text = caption
-      )
-
+      caption_df <- meta_analysis(tidy_df, type = "bayes", k = k)
       caption <- caption_df$expression[[1]]
     }
   }
 
   # basic plot -------------------------
 
-  # palette check is necessary only if output is a plot
   if (output == "plot") {
-    # setting up the basic architecture
     plot <- ggplot(tidy_df, mapping = aes(estimate, term)) +
       exec(geom_point, !!!point.args)
 
@@ -343,30 +303,25 @@ ggcoefstats <- function(x,
 
     # ggrepel labels -------------------------
 
-    # adding the labels
     if (stats.labels) {
-      # use a palette, assuming enough no. of colors are available
       if (is.null(stats.label.color) && palette_message(package, palette, length(tidy_df$term))) {
         stats.label.color <- paletteer::paletteer_d(paste0(package, "::", palette), length(tidy_df$term))
-      } else {
-        stats.label.color <- "black"
       }
 
-      # adding labels
       plot <- plot +
         exec(
           ggrepel::geom_label_repel,
           data    = tidy_df,
-          mapping = aes(x = estimate, y = term, label = label),
+          mapping = aes(x = estimate, y = term, label = expression),
           parse   = TRUE,
-          color   = stats.label.color,
+          color   = stats.label.color %||% "black",
+          na.rm   = TRUE,
           !!!stats.label.args
         )
     }
 
     # annotations -------------------------
 
-    # adding other labels to the plot
     plot <- plot +
       labs(
         x        = xlab %||% "estimate",
@@ -381,12 +336,11 @@ ggcoefstats <- function(x,
 
   # output -------------------------
 
-  # what needs to be returned?
   switch(output,
     "subtitle" = subtitle,
     "caption"  = caption,
-    "tidy"     = as_tibble(tidy_df),
-    "glance"   = as_tibble(glance_df),
+    "tidy"     = tidy_df,
+    "glance"   = glance_df,
     plot
   )
 }
