@@ -6,6 +6,9 @@
 #' by the author to be aesthetically pleasing to the user/reader. The theme is a
 #' wrapper around `theme_bw()`.
 #'
+#' All `{ggstatsplot}` functions have a `ggtheme` parameter that let you choose
+#' a different theme.
+#'
 #' @return A `ggplot` object with the `theme_ggstatsplot` theme overlaid.
 #'
 #' @examples
@@ -16,26 +19,25 @@
 #'   geom_point() +
 #'   theme_ggstatsplot()
 #' @export
-
-# function body
 theme_ggstatsplot <- function() {
-  theme_bw() +
+  theme_bw(base_size = 10) +
     theme(
-      axis.title    = element_text(face = "bold"),
-      legend.text   = element_text(size = 10),
-      legend.title  = element_text(size = 10, face = "bold"),
-      plot.title    = element_text(size = 12, face = "bold"),
-      plot.subtitle = element_text(size = 10),
-      panel.border  = element_blank(),
-      strip.text    = element_text(face = "bold")
+      axis.title         = element_text(face = "bold"),
+      axis.title.y.right = element_text(size = 8),
+      legend.title       = element_text(face = "bold"),
+      plot.title         = element_text(size = 12, face = "bold"),
+      panel.border       = element_blank(),
+      strip.text         = element_text(face = "bold")
     )
 }
 
 #' @title Split dataframe into a list by grouping variable.
-#' @description This function splits the dataframe into a list, with the length
-#'   of the list equal to the factor levels of the grouping variable. Each
-#'   element of the list will be a tibble.
-#' @name grouped_list
+#'
+#' @description
+#'
+#' This function splits the data frame into a list, with the length of the list
+#' equal to the factor levels of the grouping variable. Each element of the list
+#' will be a tibble.
 #'
 #' @inheritParams ggbetweenstats
 #' @param grouping.var A single grouping variable.
@@ -45,8 +47,6 @@ theme_ggstatsplot <- function() {
 #' ggstatsplot:::grouped_list(ggplot2::msleep, grouping.var = vore)
 #' }
 #' @keywords internal
-
-# function body
 grouped_list <- function(data, grouping.var = NULL) {
   # ensure the grouping variable works quoted or unquoted
   if (quo_is_null(enquo(grouping.var))) {
@@ -66,8 +66,6 @@ grouped_list <- function(data, grouping.var = NULL) {
 #'   colors allowed by `"Dark2"` palette from the `RColorBrewer` package.
 #'
 #' @noRd
-
-# function body
 palette_message <- function(package, palette, min_length) {
   # computing the palette length
   filter(paletteer::palettes_d_names, package == !!package, palette == !!palette) %$%
@@ -78,9 +76,9 @@ palette_message <- function(package, palette, min_length) {
 
   # inform the user
   if (!pl_message) {
-    message(cat(
-      "Warning: Number of labels is greater than default palette color count.\n",
-      "Try using another color `palette` (and/or `package`).\n"
+    rlang::warn(paste0(
+      "Number of labels is greater than default palette color count.",
+      "Select another color `palette` (and/or `package`)."
     ))
   }
 
